==> fake-bpy-module-2.78-20210304.tar.gz: fake-bpy-module-2.78-20210304/bl_operators/object_align.py <==
import sys
import typing
import bpy_types


class AlignObjects(bpy_types.Operator):
    align_axis = None
    ''' '''

    align_mode = None
    ''' '''

    bb_quality = None
    ''' '''

    bl_idname = None
    ''' '''

    bl_label = None
    ''' '''

    bl_options = None
    ''' '''

    bl_rna = None
    ''' '''

    id_data = None
    ''' '''

    order = None
    ''' '''

    relative_to = None
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        pass

    def as_pointer(self):
        ''' 

        '''
        pass

    def driver_add(self):
        ''' 

        '''
        pass

    def driver_remove(self):
        ''' 

        '''
        pass

    def execute(self, context):
        ''' 

        '''
        pass

    def get(self):
        ''' 

        '''
        pass

    def is_property_hidden(self):
        ''' 

        '''
        pass

    def is_property_readonly(self):
        ''' 

        '''
        pass

    def is_property_set(self):
        ''' 

        '''
        pass

    def items(self):
        ''' 

        '''
        pass

    def keyframe_delete(self):
        ''' 

        '''
        pass

    def keyframe_insert(self):
        ''' 

        '''
        pass

    def keys(self):
        ''' 

        '''
        pass

    def path_from_id(self):
        ''' 

        '''
        pass

    def path_resolve(self):
        ''' 

        '''
        pass

    def poll(self, context):
        ''' 

        '''
        pass

    def property_unset(self):
        ''' 

        '''
        pass

    def type_recast(self):
        ''' 

        '''
        pass

    def values(self):
        ''' 

        '''
        pass


def GlobalBB_HQ(obj):
    ''' 

    '''

    pass


def GlobalBB_LQ(bb_world):
    ''' 

    '''

    pass


def align_objects(context, align_x, align_y, align_z, align_mode, relative_to,
                  bb_quality):
    ''' 

    '''

    pass

==> fake-bpy-module-2.79-20211212.tar.gz: fake-bpy-module-2.79-20211212/bl_operators/object_align.py <==
import sys
import typing
import bpy_types


class AlignObjects(bpy_types.Operator):
    align_axis = None
    ''' '''

    align_mode = None
    ''' '''

    bb_quality = None
    ''' '''

    bl_idname = None
    ''' '''

    bl_label = None
    ''' '''

    bl_options = None
    ''' '''

    bl_rna = None
    ''' '''

    id_data = None
    ''' '''

    order = None
    ''' '''

    relative_to = None
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        pass

    def as_pointer(self):
        ''' 

        '''
        pass

    def driver_add(self):
        ''' 

        '''
        pass

    def driver_remove(self):
        ''' 

        '''
        pass

    def execute(self, context):
        ''' 

        '''
        pass

    def get(self):
        ''' 

        '''
        pass

    def is_property_hidden(self):
        ''' 

        '''
        pass

    def is_property_readonly(self):
        ''' 

        '''
        pass

    def is_property_set(self):
        ''' 

        '''
        pass

    def items(self):
        ''' 

        '''
        pass

    def keyframe_delete(self):
        ''' 

        '''
        pass

    def keyframe_insert(self):
        ''' 

        '''
        pass

    def keys(self):
        ''' 

        '''
        pass

    def path_from_id(self):
        ''' 

        '''
        pass

    def path_resolve(self):
        ''' 

        '''
        pass

    def poll(self, context):
        ''' 

        '''
        pass

    def property_unset(self):
        ''' 

        '''
        pass

    def type_recast(self):
        ''' 

        '''
        pass

    def values(self):
        ''' 

        '''
        pass


def align_objects(context, align_x, align_y, align_z, align_mode, relative_to,
                  bb_quality):
    ''' 

    '''

    pass


def worldspace_bounds_from_object_bounds(bb_world):
    ''' 

    '''

    pass


def worldspace_bounds_from_object_data(scene, obj):
    ''' 

    '''

    pass
